@@ -135,7 +135,9 @@ class MyWhatify:
             if skip_if_exist:
                 ret_list = cls.get_prediction_list(search_term=data_name)
                 if len(ret_list) > 0:
-                    return int(ret_list[0]['id']), True, None
+                    for pred_check in ret_list:
+                        if pred_check['ensemble_id'] == ensemble_id:
+                            return int(ret_list[0]['id']), True, None
             try:
                 if not (file_path or data_id):
                     data_id = my_toolkit.Datasource.create_from_dataframe(df=data_file, data_source_name=data_name,
@@ -454,8 +456,8 @@ class MyWhatify:
     def get_pipeline_estimators_list(cls, dataset_id, is_pipeline=True, interpt_level=Interpt.PRECISE):
         """
         getting the Dataset pipeline or estimators list for dataset_id
-        :param dataset_id:
-        :param is_pipeline:
+        :param dataset_id: Dataset ID
+        :param is_pipeline: get pipeline (default True) or estimators (False)
         :param interpt_level:
         :return:
         """
@@ -474,9 +476,9 @@ class MyWhatify:
         get prediction list by search term
         :param len: len of the return prediction list
         :param search_term: search term to filter the prediction list
-        :return:
+        :return: list of prediction for search term or by len
         """
-        with allure.step('getting the prediction list for the prediction_name: ' + str(search_term)):
+        with allure.step('getting the prediction list limit by len for the prediction_name: ' + str(search_term)):
             return my_toolkit.Prediction.list(search_term=search_term)['hits'][0:len]
 
     @classmethod
@@ -485,7 +487,7 @@ class MyWhatify:
         get prediction list for predict ID
         :param predict_id: prediction ID
         :param len: len of the return prediction list (None for all)
-        :return:
+        :return: list of prediction limit by len (None = no limit) for predict ID
         """
         with allure.step('getting prediction list for predict_id: ' + str(predict_id) + ' len: ' + str(len)):
             ret_prediction = None
@@ -606,7 +608,7 @@ class MyWhatify:
         """
         get wisdom list for current user
         :return:
-        wisdom list
+        wisdom object list
         """
         with allure.step('getting wisdom list with search term: ' + str(search_term)):
             my_list = my_toolkit.Wisdom.get_wisdom_list_with_demo(search_term=search_term)
@@ -629,7 +631,7 @@ class MyWhatify:
         get wisdom for current user by ID
         :param wisdom_id:
         :return:
-        wisdom
+        wisdom object
         """
         with allure.step(' '.join(['getting wisdom ID:', str(wisdom_id)])):
             return my_toolkit.Wisdom.get_wisdom(id=wisdom_id)
